==> fda_1.1.8.tar.gz: fda/data/dateAccessories.R <==
`dayOfYear` <-
as.integer(c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 
32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 
64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 
80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 
96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 
109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 
122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 
135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 
148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 
161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 
174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 
200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 
213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 
226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 
239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 
304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 
317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 
330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 
343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 
356, 357, 358, 359, 360, 361, 362, 363, 364, 365))
`day.5` <-
c(0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 
12.5, 13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 21.5, 22.5, 
23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 29.5, 30.5, 31.5, 32.5, 33.5, 
34.5, 35.5, 36.5, 37.5, 38.5, 39.5, 40.5, 41.5, 42.5, 43.5, 44.5, 
45.5, 46.5, 47.5, 48.5, 49.5, 50.5, 51.5, 52.5, 53.5, 54.5, 55.5, 
56.5, 57.5, 58.5, 59.5, 60.5, 61.5, 62.5, 63.5, 64.5, 65.5, 66.5, 
67.5, 68.5, 69.5, 70.5, 71.5, 72.5, 73.5, 74.5, 75.5, 76.5, 77.5, 
78.5, 79.5, 80.5, 81.5, 82.5, 83.5, 84.5, 85.5, 86.5, 87.5, 88.5, 
89.5, 90.5, 91.5, 92.5, 93.5, 94.5, 95.5, 96.5, 97.5, 98.5, 99.5, 
100.5, 101.5, 102.5, 103.5, 104.5, 105.5, 106.5, 107.5, 108.5, 
109.5, 110.5, 111.5, 112.5, 113.5, 114.5, 115.5, 116.5, 117.5, 
118.5, 119.5, 120.5, 121.5, 122.5, 123.5, 124.5, 125.5, 126.5, 
127.5, 128.5, 129.5, 130.5, 131.5, 132.5, 133.5, 134.5, 135.5, 
136.5, 137.5, 138.5, 139.5, 140.5, 141.5, 142.5, 143.5, 144.5, 
145.5, 146.5, 147.5, 148.5, 149.5, 150.5, 151.5, 152.5, 153.5, 
154.5, 155.5, 156.5, 157.5, 158.5, 159.5, 160.5, 161.5, 162.5, 
163.5, 164.5, 165.5, 166.5, 167.5, 168.5, 169.5, 170.5, 171.5, 
172.5, 173.5, 174.5, 175.5, 176.5, 177.5, 178.5, 179.5, 180.5, 
181.5, 182.5, 183.5, 184.5, 185.5, 186.5, 187.5, 188.5, 189.5, 
190.5, 191.5, 192.5, 193.5, 194.5, 195.5, 196.5, 197.5, 198.5, 
199.5, 200.5, 201.5, 202.5, 203.5, 204.5, 205.5, 206.5, 207.5, 
208.5, 209.5, 210.5, 211.5, 212.5, 213.5, 214.5, 215.5, 216.5, 
217.5, 218.5, 219.5, 220.5, 221.5, 222.5, 223.5, 224.5, 225.5, 
226.5, 227.5, 228.5, 229.5, 230.5, 231.5, 232.5, 233.5, 234.5, 
235.5, 236.5, 237.5, 238.5, 239.5, 240.5, 241.5, 242.5, 243.5, 
244.5, 245.5, 246.5, 247.5, 248.5, 249.5, 250.5, 251.5, 252.5, 
253.5, 254.5, 255.5, 256.5, 257.5, 258.5, 259.5, 260.5, 261.5, 
262.5, 263.5, 264.5, 265.5, 266.5, 267.5, 268.5, 269.5, 270.5, 
271.5, 272.5, 273.5, 274.5, 275.5, 276.5, 277.5, 278.5, 279.5, 
280.5, 281.5, 282.5, 283.5, 284.5, 285.5, 286.5, 287.5, 288.5, 
289.5, 290.5, 291.5, 292.5, 293.5, 294.5, 295.5, 296.5, 297.5, 
298.5, 299.5, 300.5, 301.5, 302.5, 303.5, 304.5, 305.5, 306.5, 
307.5, 308.5, 309.5, 310.5, 311.5, 312.5, 313.5, 314.5, 315.5, 
316.5, 317.5, 318.5, 319.5, 320.5, 321.5, 322.5, 323.5, 324.5, 
325.5, 326.5, 327.5, 328.5, 329.5, 330.5, 331.5, 332.5, 333.5, 
334.5, 335.5, 336.5, 337.5, 338.5, 339.5, 340.5, 341.5, 342.5, 
343.5, 344.5, 345.5, 346.5, 347.5, 348.5, 349.5, 350.5, 351.5, 
352.5, 353.5, 354.5, 355.5, 356.5, 357.5, 358.5, 359.5, 360.5, 
361.5, 362.5, 363.5, 364.5)
`daysPerMonth` <-
structure(c(31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31), .Names = c("Jan", 
"Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", 
"Nov", "Dec"))
`monthEnd` <-
structure(c(31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 
365), .Names = c("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", 
"Aug", "Sep", "Oct", "Nov", "Dec"))
`monthEnd.5` <-
structure(c(30.5, 58.5, 89.5, 119.5, 150.5, 180.5, 211.5, 242.5, 
272.5, 303.5, 333.5, 364.5), .Names = c("Jan", "Feb", "Mar", 
"Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
))
`monthBegin.5` <-
structure(c(0.5, 31.5, 59.5, 90.5, 120.5, 151.5, 181.5, 212.5, 
243.5, 273.5, 304.5, 334.5), .Names = c("Jan", "Feb", "Mar", 
"Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
))
`monthMid` <-
structure(c(15.5, 45, 74.5, 105, 135.5, 166, 196.5, 227.5, 258, 
288.5, 319, 349.5), .Names = c("Jan", "Feb", "Mar", "Apr", "May", 
"Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"))
`monthLetters` <-
structure(c("j", "F", "m", "A", "M", "J", "J", "A", "S", "O", 
"N", "D"), .Names = c("Jan", "Feb", "Mar", "Apr", "May", "Jun", 
"Jul", "Aug", "Sep", "Oct", "Nov", "Dec"))
`weeks` <-
structure(c(0, 7.01923076923077, 14.0384615384615, 21.0576923076923, 
28.0769230769231, 35.0961538461538, 42.1153846153846, 49.1346153846154, 
56.1538461538462, 63.1730769230769, 70.1923076923077, 77.2115384615385, 
84.2307692307692, 91.25, 98.2692307692308, 105.288461538462, 
112.307692307692, 119.326923076923, 126.346153846154, 133.365384615385, 
140.384615384615, 147.403846153846, 154.423076923077, 161.442307692308, 
168.461538461538, 175.480769230769, 182.5, 189.519230769231, 
196.538461538462, 203.557692307692, 210.576923076923, 217.596153846154, 
224.615384615385, 231.634615384615, 238.653846153846, 245.673076923077, 
252.692307692308, 259.711538461538, 266.730769230769, 273.75, 
280.769230769231, 287.788461538462, 294.807692307692, 301.826923076923, 
308.846153846154, 315.865384615385, 322.884615384615, 329.903846153846, 
336.923076923077, 343.942307692308, 350.961538461538, 357.980769230769, 
365), .Names = c("week0", "week1", "week2", "week3", "week4", 
"week5", "week6", "week7", "week8", "week9", "week10", "week11", 
"week12", "week13", "week14", "week15", "week16", "week17", "week18", 
"week19", "week20", "week21", "week22", "week23", "week24", "week25", 
"week26", "week27", "week28", "week29", "week30", "week31", "week32", 
"week33", "week34", "week35", "week36", "week37", "week38", "week39", 
"week40", "week41", "week42", "week43", "week44", "week45", "week46", 
"week47", "week48", "week49", "week50", "week51", "week52"))

==> fda_1.2.1-1.tar.gz: fda/data/dateAccessories.R <==
`dayOfYear` <-
as.integer(c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 
32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 
64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 
80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 
96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 
109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 
122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 
135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 
148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 
161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 
174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 
200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 
213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 
226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 
239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 
304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 
317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 
330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 
343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 
356, 357, 358, 359, 360, 361, 362, 363, 364, 365))
`day.5` <-
c(0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 
12.5, 13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 21.5, 22.5, 
23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 29.5, 30.5, 31.5, 32.5, 33.5, 
34.5, 35.5, 36.5, 37.5, 38.5, 39.5, 40.5, 41.5, 42.5, 43.5, 44.5, 
45.5, 46.5, 47.5, 48.5, 49.5, 50.5, 51.5, 52.5, 53.5, 54.5, 55.5, 
56.5, 57.5, 58.5, 59.5, 60.5, 61.5, 62.5, 63.5, 64.5, 65.5, 66.5, 
67.5, 68.5, 69.5, 70.5, 71.5, 72.5, 73.5, 74.5, 75.5, 76.5, 77.5, 
78.5, 79.5, 80.5, 81.5, 82.5, 83.5, 84.5, 85.5, 86.5, 87.5, 88.5, 
89.5, 90.5, 91.5, 92.5, 93.5, 94.5, 95.5, 96.5, 97.5, 98.5, 99.5, 
100.5, 101.5, 102.5, 103.5, 104.5, 105.5, 106.5, 107.5, 108.5, 
109.5, 110.5, 111.5, 112.5, 113.5, 114.5, 115.5, 116.5, 117.5, 
118.5, 119.5, 120.5, 121.5, 122.5, 123.5, 124.5, 125.5, 126.5, 
127.5, 128.5, 129.5, 130.5, 131.5, 132.5, 133.5, 134.5, 135.5, 
136.5, 137.5, 138.5, 139.5, 140.5, 141.5, 142.5, 143.5, 144.5, 
145.5, 146.5, 147.5, 148.5, 149.5, 150.5, 151.5, 152.5, 153.5, 
154.5, 155.5, 156.5, 157.5, 158.5, 159.5, 160.5, 161.5, 162.5, 
163.5, 164.5, 165.5, 166.5, 167.5, 168.5, 169.5, 170.5, 171.5, 
172.5, 173.5, 174.5, 175.5, 176.5, 177.5, 178.5, 179.5, 180.5, 
181.5, 182.5, 183.5, 184.5, 185.5, 186.5, 187.5, 188.5, 189.5, 
190.5, 191.5, 192.5, 193.5, 194.5, 195.5, 196.5, 197.5, 198.5, 
199.5, 200.5, 201.5, 202.5, 203.5, 204.5, 205.5, 206.5, 207.5, 
208.5, 209.5, 210.5, 211.5, 212.5, 213.5, 214.5, 215.5, 216.5, 
217.5, 218.5, 219.5, 220.5, 221.5, 222.5, 223.5, 224.5, 225.5, 
226.5, 227.5, 228.5, 229.5, 230.5, 231.5, 232.5, 233.5, 234.5, 
235.5, 236.5, 237.5, 238.5, 239.5, 240.5, 241.5, 242.5, 243.5, 
244.5, 245.5, 246.5, 247.5, 248.5, 249.5, 250.5, 251.5, 252.5, 
253.5, 254.5, 255.5, 256.5, 257.5, 258.5, 259.5, 260.5, 261.5, 
262.5, 263.5, 264.5, 265.5, 266.5, 267.5, 268.5, 269.5, 270.5, 
271.5, 272.5, 273.5, 274.5, 275.5, 276.5, 277.5, 278.5, 279.5, 
280.5, 281.5, 282.5, 283.5, 284.5, 285.5, 286.5, 287.5, 288.5, 
289.5, 290.5, 291.5, 292.5, 293.5, 294.5, 295.5, 296.5, 297.5, 
298.5, 299.5, 300.5, 301.5, 302.5, 303.5, 304.5, 305.5, 306.5, 
307.5, 308.5, 309.5, 310.5, 311.5, 312.5, 313.5, 314.5, 315.5, 
316.5, 317.5, 318.5, 319.5, 320.5, 321.5, 322.5, 323.5, 324.5, 
325.5, 326.5, 327.5, 328.5, 329.5, 330.5, 331.5, 332.5, 333.5, 
334.5, 335.5, 336.5, 337.5, 338.5, 339.5, 340.5, 341.5, 342.5, 
343.5, 344.5, 345.5, 346.5, 347.5, 348.5, 349.5, 350.5, 351.5, 
352.5, 353.5, 354.5, 355.5, 356.5, 357.5, 358.5, 359.5, 360.5, 
361.5, 362.5, 363.5, 364.5)
`daysPerMonth` <-
structure(c(31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31), .Names = c("Jan", 
"Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", 
"Nov", "Dec"))
`monthEnd` <-
structure(c(31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 
365), .Names = c("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", 
"Aug", "Sep", "Oct", "Nov", "Dec"))
`monthEnd.5` <-
structure(c(30.5, 58.5, 89.5, 119.5, 150.5, 180.5, 211.5, 242.5, 
272.5, 303.5, 333.5, 364.5), .Names = c("Jan", "Feb", "Mar", 
"Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
))
`monthBegin.5` <-
structure(c(0.5, 31.5, 59.5, 90.5, 120.5, 151.5, 181.5, 212.5, 
243.5, 273.5, 304.5, 334.5), .Names = c("Jan", "Feb", "Mar", 
"Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
))
`monthMid` <-
structure(c(15.5, 45, 74.5, 105, 135.5, 166, 196.5, 227.5, 258, 
288.5, 319, 349.5), .Names = c("Jan", "Feb", "Mar", "Apr", "May", 
"Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"))
`monthLetters` <-
structure(c("j", "FALSE", "m", "A", "M", "J", "J", "A", "S", "O", 
"N", "D"), .Names = c("Jan", "Feb", "Mar", "Apr", "May", "Jun", 
"Jul", "Aug", "Sep", "Oct", "Nov", "Dec"))
`weeks` <-
structure(c(0, 7.01923076923077, 14.0384615384615, 21.0576923076923, 
28.0769230769231, 35.0961538461538, 42.1153846153846, 49.1346153846154, 
56.1538461538462, 63.1730769230769, 70.1923076923077, 77.2115384615385, 
84.2307692307692, 91.25, 98.2692307692308, 105.288461538462, 
112.307692307692, 119.326923076923, 126.346153846154, 133.365384615385, 
140.384615384615, 147.403846153846, 154.423076923077, 161.442307692308, 
168.461538461538, 175.480769230769, 182.5, 189.519230769231, 
196.538461538462, 203.557692307692, 210.576923076923, 217.596153846154, 
224.615384615385, 231.634615384615, 238.653846153846, 245.673076923077, 
252.692307692308, 259.711538461538, 266.730769230769, 273.75, 
280.769230769231, 287.788461538462, 294.807692307692, 301.826923076923, 
308.846153846154, 315.865384615385, 322.884615384615, 329.903846153846, 
336.923076923077, 343.942307692308, 350.961538461538, 357.980769230769, 
365), .Names = c("week0", "week1", "week2", "week3", "week4", 
"week5", "week6", "week7", "week8", "week9", "week10", "week11", 
"week12", "week13", "week14", "week15", "week16", "week17", "week18", 
"week19", "week20", "week21", "week22", "week23", "week24", "week25", 
"week26", "week27", "week28", "week29", "week30", "week31", "week32", 
"week33", "week34", "week35", "week36", "week37", "week38", "week39", 
"week40", "week41", "week42", "week43", "week44", "week45", "week46", 
"week47", "week48", "week49", "week50", "week51", "week52"))
